<?php
  /**
  *
  * @author Denis Chenu <denis@sondages.pro>
  * @copyright 2017 Denis Chenu <http://sondages.pro>
  * @license AGPL v3
  * @version 1.1.1
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  */
  class tableHeaderFix extends \ls\pluginmanager\PluginBase
  {
    protected $storage = 'DbStorage';
    static protected $description = 'Allow to fix header (line or column) for array question type.';
    static protected $name = 'tableHeaderFix';

    public function init()
    {
      $this->subscribe('beforeQuestionRender');
      $this->subscribe('beforeSurveyPage');

      $this->subscribe('newQuestionAttributes');
      /* Must subscribe ONLY if no newQuestionAttributes */
      $this->subscribe('beforeSurveySettings');
      $this->subscribe('newSurveySettings');
    }

    public function beforeQuestionRender()
    {
        $oEvent = $this->getEvent();
        $iSurveyId=$oEvent->get('surveyId');

        $minColumns=$this->get('minColumns', 'Survey', $iSurveyId,'');
        $minLines=$this->get('minLines', 'Survey', $iSurveyId,'');
        if($minColumns==='' && $minLines===''){
            return;
        }
        $colActive=false;
        $lineActive=false;
        $qid=$oEvent->get('qid');
        $oSurvey=Survey::model()->findByPk($iSurveyId);
        if($oSurvey){
            $language=$oSurvey->language;
        }else{
            $language=isset($_SESSION['LEMlang']) ? $_SESSION['LEMlang'] : (isset($_SESSION['s_lang']) ? $_SESSION['s_lang'] :App()->getLanguage());
        }
        // Need only subquestion
        //"A","B","C"
        switch ($oEvent->get('type')){

            case ":":
            case ";":
                /* @todo : control scale_id */
                $colActive=($minColumns!=='' && (int)Question::model()->count("parent_qid=:qid and language=:language and scale_id=1",array(":qid"=>$qid,":language"=>$language))>=$minColumns);
                $lineActive=($minLines!=='' && (int)Question::model()->count("parent_qid=:qid and language=:language and scale_id=0",array(":qid"=>$qid,":language"=>$language))>=$minLines);
                break;
            case "F":
                $colActive=($minColumns!=='' && (int)Answer::model()->count("qid=:qid and language=:language",array(":qid"=>$qid,":language"=>$language))>=$minColumns);
            case "A":
            case "B":
            case "C":
            case "E":
                $lineActive=($minLines!=='' && (int)Question::model()->count("parent_qid=:qid and language=:language",array(":qid"=>$qid,":language"=>$language))>=$minLines);
                break;
            case "H":
            default:
                break;
        }
        if($colActive || $lineActive){
            /* 0/1 for javascript */
            $colActive=(int)$colActive;
            $lineActive=(int)$lineActive;
            $maxHeight=(int)$this->get('maxHeight', 'Survey', $iSurveyId,0);
            $assetUrl=Yii::app()->assetManager->publish(dirname(__FILE__) . '/assets');
            Yii::app()->getClientScript()->registerScriptFile($assetUrl . '/jquery.floatThead.js');
            Yii::app()->getClientScript()->registerScriptFile($assetUrl . '/tableHeaderFix.js');
            Yii::app()->getClientScript()->registerCssFile($assetUrl . '/tableHeaderFix.css');
            Yii::app()->getClientScript()->registerScript("tableHeaderFix{$qid}","tableHeaderFix({$qid},{$colActive},{$lineActive},{$maxHeight});",CClientScript::POS_END);
            $oEvent->set('class',$oEvent->get('class')." ls-tableheaderfix");
            if($colActive){
                $oEvent->set('class',$oEvent->get('class')." ls-table-colfix");
            }
            if($lineActive){
                $oEvent->set('class',$oEvent->get('class')." ls-table-linefix");
            }
            if($this->get('oneLineFix', 'Survey', $iSurveyId,0)){
                $oEvent->set('class',$oEvent->get('class')." ls-table-onelinefix");
            }
        }
    }

    public function beforeSurveySettings()
    {
        $oEvent = $this->getEvent();
        $oEvent->set("surveysettings.{$this->id}", array(
            'name' => get_class($this),
            'settings' => array(
              'infoWarning'=>array(
                'type'=>'info',
                'content'=>'<div class="alert alert-warning"><strong>Warning : </strong>If you want to use tableHearderFix plugin : remind to set the repeat_headings settings to a big number.</div>',
              ),
              'minColumns'=>array(
                'type'=>'int',
                'label'=>'Activate from (column)',
                'htmlOptions'=>array(
                  'min'=>0
                ),
                'current' => $this->get('minColumns', 'Survey', $oEvent->get('survey'),''),
              ),
              'minLines'=>array(
                'type'=>'int',
                'label'=>'Activate from (lines)',
                'htmlOptions'=>array(
                  'min'=>0
                ),
                'current' => $this->get('minLines', 'Survey', $oEvent->get('survey'),''),
              ),
              'maxHeight'=>array(
                'type'=>'int',
                'label'=>'Maximum height in caracter',
                'htmlOptions'=>array(
                  'min'=>10
                ),
                'help'=>"Leave empty to use windows height",
                'current' => $this->get('maxHeight', 'Survey', $oEvent->get('survey'),''),
              ),
              'oneLineFix'=>array(
                'type'=>'checkbox',
                'value'=>1,
                'htmlOption'=>array(
                    'uncheckValue'=>0
                ),
                'label'=>'One line for answers and sub question',
                'help'=>'You can still use <code>&lt;br/&gt;</code> for new line',
                'current' => $this->get('oneLineFix', 'Survey', $oEvent->get('survey'),0),
              ),
            ),
        ));
    }

    public function newSurveySettings()
    {
        $event = $this->event;
        foreach ($event->get('settings') as $name => $value)
        {
            $this->set($name, $value, 'Survey', $event->get('survey'));
        }
    }
    public function beforeSurveyPage()
    {
        $oEvent = $this->getEvent();
        $iSurveyId=$oEvent->get('surveyId');

        $minColumns=$this->get('minColumns', 'Survey', $iSurveyId,'');
        $minLines=$this->get('minLines', 'Survey', $iSurveyId,'');
        if($minColumns==='' && $minLines===''){
            return;
        }
        App()->setConfig("repeatheadings",10000000000000);
        App()->setConfig("minrepeatheadings",10000000000000);
    }
    public function newQuestionAttributes(){

    }

  }
?>
